@@ -1,13 +1,11 @@
 from groundx.paths.v1_project_project_id.get import ApiForget
 from groundx.paths.v1_project_project_id.put import ApiForput
-from groundx.paths.v1_project_project_id.post import ApiForpost
 from groundx.paths.v1_project_project_id.delete import ApiFordelete
 
 
 class V1ProjectProjectId(
     ApiForget,
     ApiForput,
-    ApiForpost,
     ApiFordelete,
 ):
     pass
