@@ -13,9 +13,8 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
 from groundx.type.document_remote_upload_request_documents_item import DocumentRemoteUploadRequestDocumentsItem
-from groundx.type.document_type import DocumentType
 
 DocumentRemoteUploadRequestDocuments = typing.List[DocumentRemoteUploadRequestDocumentsItem]
